@@ -1,7 +1,7 @@
 import json
 
 import numpy as np
-from metacity.datamodel.layer.layer import MetacityLayer
+from metacity.datamodel.layer.layer import Layer
 from metacity.filesystem import layer as fs
 from metacity.io.cityjson.object import CJObject
 
@@ -19,16 +19,16 @@ class CJParser:
     def is_empty(self):
         return len(self.vertices) == 0 or len(self.objects) == 0
 
-    def adjust_data(self, layer: MetacityLayer):
+    def adjust_data(self, layer: Layer):
         layer.config.apply(self.vertices)
 
-    def parse_and_export(self, layer: MetacityLayer):
+    def parse_and_export(self, layer: Layer):
         for oid, data in self.objects.items():
             object = CJObject(oid, data, self.vertices, self.templates)
             object.export(layer.geometry_path, layer.meta_path)
 
 
-def parse(layer: MetacityLayer, input_file: str):
+def parse(layer: Layer, input_file: str):
     with open(input_file, "r") as file:
         contents = json.load(file)
 
